==> haskell-ghc-syntax-highlighter-0.0.9.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-syntax-highlighter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-syntax-highlighter
version:              0.0.9.0
visibility:           public
id:                   ghc-syntax-highlighter-0.0.9.0-6bYzf6VAQSMlrkGldU1iM
key:                  ghc-syntax-highlighter-0.0.9.0-6bYzf6VAQSMlrkGldU1iM
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/ghc-syntax-highlighter
synopsis:             Syntax highlighter for Haskell using the lexer of GHC
description:          Syntax highlighter for Haskell using the lexer of GHC.
category:             Text
abi:                  5cbe348b66b85d062dd2b08d3e642088
exposed:              True
exposed-modules:      GHC.SyntaxHighlighter
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-syntax-highlighter
hs-libraries:         HSghc-syntax-highlighter-0.0.9.0-6bYzf6VAQSMlrkGldU1iM
depends:
    base-4.17.2.1 ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-syntax-highlighter/html/ghc-syntax-highlighter.haddock

haddock-html:         /usr/share/doc/haskell-ghc-syntax-highlighter/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-syntax-highlighter-0.0.9.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-syntax-highlighter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-syntax-highlighter
version:              0.0.9.0
visibility:           public
id:                   ghc-syntax-highlighter-0.0.9.0-2SF9YuJZQAy4QYy4Cei6CD
key:                  ghc-syntax-highlighter-0.0.9.0-2SF9YuJZQAy4QYy4Cei6CD
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/ghc-syntax-highlighter
synopsis:             Syntax highlighter for Haskell using the lexer of GHC
description:          Syntax highlighter for Haskell using the lexer of GHC.
category:             Text
abi:                  a768ec49ec1746c17b3bcfbb8ec46e7d
exposed:              True
exposed-modules:      GHC.SyntaxHighlighter
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/ghc-syntax-highlighter-0.0.9.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-syntax-highlighter
hs-libraries:         HSghc-syntax-highlighter-0.0.9.0-2SF9YuJZQAy4QYy4Cei6CD
depends:
    base-4.17.2.1 ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-syntax-highlighter/html/ghc-syntax-highlighter.haddock

haddock-html:         /usr/share/doc/haskell-ghc-syntax-highlighter/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
